package churchillobjects.rss4j;

/**
 * This class is used to add subnodes to the RssJbnPatch class.  Each dependency hs a name and a unique URL that
 * identifies the dependency.
 *
 * @author <a href="mailto:jessica.sant@jboss.com">Jessica Sant</a>
 * @version $Revision: 1.1 $
 */
public class RssJbnDependency
{
    public static final String ATTR_JON_RESOURCE_TYPE = "jonResourceType";
    public static final String ATTR_JON_RESOURCE_VERSION = "jonResourceVersion";
    public static final String ATTR_PRODUCT_NAME = "productName";
    public static final String ATTR_PRODUCT_VERSION = "productVersion";


    /** unique URL that identifies this dependency (used in all dependency types) */
    private String url;
    /** name that describes this dependency (used in all dependency types) */
    private String name;

    /** the name by which JBoss ON recognizes this product (used in <jbn:product/> types) */
    private String jonResourceType;
    /** the string by which JBoss ON recognizes this product version (used in <jbn:product/> types)*/
    private String jonResourceVersion;
    /** the name by which the FEED recognizes this product (used in <jbn:product/> types)*/
    private String productName;
    /** the string by which the FEED recognizes this product version (used in <jbn:product/> types)*/
    private String productVersion;


    public RssJbnDependency()
    {
        // empty constructor    
    }

    public RssJbnDependency(String baseURL, String moreURL, String id, String firstValue, String secondValue )
    {
        this( baseURL + moreURL + id, firstValue != null ? firstValue + "; " + secondValue : secondValue );
    }

    public RssJbnDependency( String url, String name )
    {
        this.url = url;
        this.name = name;
    }

    public RssJbnDependency( String url, String name, String productName, String productVersion, String jonResourceType, String jonResourceVersion )
    {
        this.url = url;
        this.name = name;
        this.productName = productName;
        this.productVersion = productVersion;
        this.jonResourceType = jonResourceType;
        this.jonResourceVersion = jonResourceVersion;
    }

    public String getUrl()
    {
        return url;
    }

    public void setUrl( String url )
    {
        this.url = url;
    }

    public String getName()
    {
        return name;
    }

    public void setName( String name )
    {
        this.name = name;
    }

    public String getProductName()
    {
        return productName;
    }

    public void setProductName( String productName )
    {
        this.productName = productName;
    }

    public String getProductVersion()
    {
        return productVersion;
    }

    public void setProductVersion( String productVersion )
    {
        this.productVersion = productVersion;
    }

    public String getJonResourceType()
    {
        return jonResourceType;
    }

    public void setJonResourceType( String jonResourceType )
    {
        this.jonResourceType = jonResourceType;
    }

    public String getJonResourceVersion()
    {
        return jonResourceVersion;
    }

    public void setJonResourceVersion( String jonResourceVersion )
    {
        this.jonResourceVersion = jonResourceVersion;
    }

    public String toString()
    {
        StringBuffer sb = new StringBuffer();
        sb.append( "[name] " );
        sb.append( this.getName() );
        sb.append( " [url] " );
        sb.append( this.getUrl() );
        sb.append( "[resourceType] ");
        sb.append( this.jonResourceType );
        sb.append( "[resourceVersion] " );
        sb.append( this.jonResourceVersion );
        return sb.toString();
    }

    public boolean equals( Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( o == null || getClass() != o.getClass() )
        {
            return false;
        }

        final RssJbnDependency that = (RssJbnDependency) o;

        if ( name != null ? !name.equals( that.name ) : that.name != null )
        {
            return false;
        }
        if ( url != null ? !url.equals( that.url ) : that.url != null )
        {
            return false;
        }
        if ( productName != null ? !productName.equals( that.productName ) : that.productName != null )
        {
            return false;
        }
        if ( productVersion != null ? !productVersion.equals( that.productVersion ) : that.productVersion != null )
        {
            return false;
        }
        if ( jonResourceType != null ? !jonResourceType.equals( that.jonResourceType ) : that.jonResourceType != null )
        {
            return false;
        }
        if ( jonResourceVersion != null ? !jonResourceVersion.equals( that.jonResourceVersion ) : that.jonResourceVersion != null )
        {
            return false;
        }

        return true;
    }

    public int hashCode()
    {
        int result;
        result = ( url != null ? url.hashCode() : 0 );
        result = 29 * result + ( name != null ? name.hashCode() : 0 );
        result = 29 * result + ( productName != null ? productName.hashCode() : 0 );
        result = 29 * result + ( productVersion != null ? productVersion.hashCode() : 0 );
        result = 29 * result + ( jonResourceType != null ? jonResourceType.hashCode() : 0 );
        result = 29 * result + ( jonResourceVersion != null ? jonResourceVersion.hashCode() : 0 );
        return result;
    }
}
