package churchillobjects.rss4j;

import churchillobjects.rss4j.model.DateLanguageUtil;

import java.io.Serializable;
import java.util.*;
import java.text.ParseException;

/**
 * [class description]
 *
 * @author <a href="mailto:jessica.sant@jboss.com">Jessica Sant</a>
 * @version $Revision: 1.1 $
 */
public class RssJbnPatch implements Cloneable, Serializable
{
    /** The XML namespace of the dublin core.  */
    public static final String XMLNS = "xmlns:jbn";

    /**  The prefix for dublin core elements. */
    public static final String PREFIX = "jbn";

    /** The namespace uri for dublin core.  */
    public static final String XMLNS_VALUE = "http://network.jboss.com/elements/1.0/";

    public static final String ATTR_TYPE = "type";
    public static final String ATTR_JIRA = "jira";
    public static final String ATTR_MD5 = "md5";
    public static final String ATTR_SHA256 = "sha256";
    public static final String ATTR_FILE_NAME = "fileName";
    public static final String ATTR_FILE_SIZE = "fileSize";
    public static final String ATTR_PRODUCTS = "products";
    public static final String ATTR_PRODUCT = "product";
    public static final String ATTR_LONG_DESC = "longDescription";
    public static final String ATTR_SHORT_DESC = "shortDescription";
    public static final String ATTR_MANUAL_INSTALL = "manualInstallation";
    public static final String ATTR_AUTOMATED_INSTALL = "automatedInstallation";
    public static final String ATTR_INSTRUCTION_SET = "instructionSet";
    public static final String ATTR_REQUIRES = "requires";
    public static final String ATTR_IS_REPLACED_BY = "isReplacedBy";
    public static final String ATTR_REPLACES = "replaces";
    public static final String ATTR_COMPATIBLE_WITH = "compatibleWith";
    public static final String ATTR_PATCH = "patch";
    public static final String ATTR_LAST_UPDATED = "lastUpdated";
    public static final String ATTR_CREATOR ="creator";
    public static final String ATTR_CASE_ID = "caseId";
    public static final String ATTR_LICENSE_NAME = "licenseName";
    public static final String ATTR_LICENSE_VERSION = "licenseVersion";
    public static final String ATTR_DISTRIBUTION_STATUS = "distributionStatus";
    public static final String ATTR_DOWNLOAD_URL = "downloadUrl";
    public static final String ATTR_AUTOMATED_DOWNLOAD_URL = "automatedDownloadUrl";
    public static final String ATTR_INSTRUCTION_VERSION = "instructionCompatibilityVersion";

    /** the products that this patch or product relates to */
    private Collection products;
    /** the type of software this is (distribution, bugfix, enhancement, etc */
    private String type;
    /** the JIRA or bug-id for this patch */
    private String jira;
    /** the MD5 checksum for this software */
    private String md5;
    /** the SHA-256 checksum for this software */
    private String sha256;
    /** the filename for this software */
    private String fileName;
    /** the size of this file */
    private String fileSize;
    /** a long description of the software */
    private String longDescription;
    /** a short description of the software */
    private String shortDescription;
    /** the manual installation instructions for this patch */
    private String manualInstallation;
    /** the automated installation instructions for this patch */
    private String automatedInstallation;
    /** a set of automated installation instructions for this patch */
    private Collection automatedInstallationSet;
    /** all the software that is required for this software to work correctly */
    private Collection requires;
    /** all the software that this software is replaced by */
    private Collection replacedBy;
    /** all the software that replaces this software */
    private Collection replaces;
    /** all software that this software is compatible with */
    private Collection compatibleWith;
    /** who created this patch */
    private String creator;
    /** when this software was last updated */
    private Date lastUpdated;
    /** the support case ID for this patch */
    private String caseId;
    /** the license that this sofware uses */
    private String licenseName;
    /** the license version that this software uses */
    private String licenseVersion;
    /** the distribution status of this software: (available, removed, obsolete, etc) */
    private String distributionStatus;
    /** the URL where the software can be downloaded from by a person */
    private String downloadUrl;
    /** the URL where the software can be downloaded by JBoss ON (or httpclient) */
    private String automatedDownloadUrl;
    /** the version of ON that these instructions are compatible with */
    private String instructionCompatibilityVersion;

    public RssJbnPatch()
    {
        products = new HashSet();
        requires = new HashSet();
        replacedBy = new HashSet();
        replaces = new HashSet();
        compatibleWith = new HashSet();
        automatedInstallationSet = new HashSet();
    }

    public Collection getRequiresNames()
    {
        ArrayList result = null;
        if( this.requires != null )
        {
            Iterator iterator = this.requires.iterator();
            result = new ArrayList( this.requires.size() );
            while( iterator.hasNext() )
            {
                // add to array here
            }
        }
        return result;
    }


    public Collection getProducts()
    {
        return products;
    }

    public void setProducts( Collection products )
    {
        this.products = products;
    }

    public void addProduct( RssJbnDependency product )
    {
        this.products.add( product );
    }

    public String getType()
    {
        return type;
    }

    public void setType( String type )
    {
        this.type = type;
    }

    public String getJira()
    {
        return jira;
    }

    public void setJira( String jira )
    {
        this.jira = jira;
    }

    public String getMd5()
    {
        return md5;
    }

    public void setMd5( String md5 )
    {
        this.md5 = md5;
    }

    public String getSha256()
    {
        return sha256;
    }

    public void setSha256( String sha256 )
    {
        this.sha256 = sha256;
    }

    public String getFileName()
    {
        return fileName;
    }

    public void setFileName( String fileName )
    {
        this.fileName = fileName;
    }

    public String getFileSize()
    {
        return fileSize;
    }

    public void setFileSize( String fileSize )
    {
        this.fileSize = fileSize;
    }

    public String getShortDescription()
    {
        return shortDescription;
    }

    public void setShortDescription( String shortDescription )
    {
        this.shortDescription = shortDescription;
    }

    public String getLongDescription()
    {
        return longDescription;
    }

    public void setLongDescription( String longDescription )
    {
        this.longDescription = longDescription;
    }

    public String getManualInstallation()
    {
        return manualInstallation;
    }

    public void setManualInstallation( String manualInstallation )
    {
        this.manualInstallation = manualInstallation;
    }

    public String getAutomatedInstallation()
    {
        return automatedInstallation;
    }

    public void setAutomatedInstallation( String automatedInstallation )
    {
        this.automatedInstallation = automatedInstallation;
    }

    public Collection getAutomatedInstallationSet()
    {
        return automatedInstallationSet;
    }

    public void setAutomatedInstallationSet( Collection automatedInstallationSet )
    {
        this.automatedInstallationSet = automatedInstallationSet;
    }

    public void addAutomatedInstallationSet( RssJbnDependency automated )
    {
        this.automatedInstallationSet.add( automated );
    }

   public Collection getRequires()
    {
        return requires;
    }

    public void setRequires( Collection requires )
    {
        this.requires = requires;
    }

    public void addRequires( RssJbnDependency requires )
    {
        this.requires.add( requires );
    }

    public Collection getReplacedBy()
    {
        return replacedBy;
    }

    public void setReplacedBy( Collection replacedBy )
    {
        this.replacedBy = replacedBy;
    }

    public void addReplacedBy( RssJbnDependency replacedBy )
    {
        this.replacedBy.add( replacedBy );
    }

    public Collection getReplaces()
    {
        return replaces;
    }

    public void setReplaces( Collection replaces )
    {
        this.replaces = replaces;
    }

    public void addReplaces( RssJbnDependency replaces )
    {
        this.replaces.add( replaces );
    }

    public Collection getCompatibleWith()
    {
        return compatibleWith;
    }

    public void setCompatibleWith( Collection compatibleWith )
    {
        this.compatibleWith = compatibleWith;
    }

    public void addCompatibleWith( RssJbnDependency compatibleWith )
    {
        this.compatibleWith.add( compatibleWith );
    }

    public String getCreator()
    {
        return creator;
    }

    public void setCreator( String creator )
    {
        this.creator = creator;
    }

    public void setLastUpdated( String stringDate ) throws ParseException
    {
        this.setLastUpdated( DateLanguageUtil.convert8601ToDate( stringDate ) );
    }

    public String getLastUpdatedAsString()
    {
        return DateLanguageUtil.convertDateTo8601( this.getLastUpdated() );
    }

    public Date getLastUpdated()
    {
        return lastUpdated;
    }

    public void setLastUpdated( Date lastUpdated )
    {
        this.lastUpdated = lastUpdated;
    }

    public String getCaseId()
    {
        return caseId;
    }

    public void setCaseId( String caseId )
    {
        this.caseId = caseId;
    }

    public String getLicenseName()
    {
        return licenseName;
    }

    public void setLicenseName( String licenseName )
    {
        this.licenseName = licenseName;
    }

    public String getLicenseVersion()
    {
        return licenseVersion;
    }

    public void setLicenseVersion( String licenseVersion )
    {
        this.licenseVersion = licenseVersion;
    }

    public String getDistributionStatus()
    {
        return distributionStatus;
    }

    public void setDistributionStatus( String distributionStatus )
    {
        this.distributionStatus = distributionStatus;
    }

    public String getDownloadUrl()
    {
        return downloadUrl;
    }

    public void setDownloadUrl( String downloadUrl )
    {
        this.downloadUrl = downloadUrl;
    }

    public String getAutomatedDownloadUrl()
    {
        return automatedDownloadUrl;
    }

    public void setAutomatedDownloadUrl( String automatedDownloadUrl )
    {
        this.automatedDownloadUrl = automatedDownloadUrl;
    }

    public String getInstructionCompatibilityVersion()
    {
        return instructionCompatibilityVersion;
    }

    public void setInstructionCompatibilityVersion( String instructionCompatibilityVersion )
    {
        this.instructionCompatibilityVersion = instructionCompatibilityVersion;
    }

    public String toString()
    {
        StringBuffer sb = new StringBuffer();
        sb.append( "type: "); sb.append( this.getType()); sb.append( ", " );
        sb.append( "jira: "); sb.append(  this.getJira()); sb.append( ", " );
        sb.append( "md5: "); sb.append( this.getMd5()); sb.append( ", " );
        sb.append( "sha-256: "); sb.append( this.getSha256()); sb.append( ", " );
        sb.append( "long Desc: "); sb.append(  this.getLongDescription()); sb.append( ", " );
        sb.append( "manual Install: "); sb.append(  this.getManualInstallation()); sb.append( ", " );
        sb.append( "automated Install: "); sb.append(  this.getAutomatedInstallation()); sb.append( ", " );
        sb.append( "creator: "); sb.append(  this.getCreator()); sb.append( ", " );
        sb.append( "date: + "); sb.append(  this.getLastUpdatedAsString()); sb.append( ", " );

        return sb.toString();
    }

    public boolean equals( Object o )
    {
        if ( this == o )
        {
            return true;
        }
        if ( o == null || getClass() != o.getClass() )
        {
            return false;
        }

        final RssJbnPatch that = (RssJbnPatch) o;

        if ( automatedInstallation != null ? !automatedInstallation.equals( that.automatedInstallation ) : that.automatedInstallation != null )
        {
            return false;
        }
        if ( caseId != null ? !caseId.equals( that.caseId ) : that.caseId != null )
        {
            return false;
        }
        if ( creator != null ? !creator.equals( that.creator ) : that.creator != null )
        {
            return false;
        }
        if ( distributionStatus != null ? !distributionStatus.equals( that.distributionStatus ) : that.distributionStatus != null )
        {
            return false;
        }
        if ( fileName != null ? !fileName.equals( that.fileName ) : that.fileName != null )
        {
            return false;
        }
        if ( fileSize != null ? !fileSize.equals( that.fileSize ) : that.fileSize != null )
        {
            return false;
        }
        if ( jira != null ? !jira.equals( that.jira ) : that.jira != null )
        {
            return false;
        }
        if ( lastUpdated != null ? !lastUpdated.equals( that.lastUpdated ) : that.lastUpdated != null )
        {
            return false;
        }
        if ( licenseName != null ? !licenseName.equals( that.licenseName ) : that.licenseName != null )
        {
            return false;
        }
        if ( licenseVersion != null ? !licenseVersion.equals( that.licenseVersion ) : that.licenseVersion != null )
        {
            return false;
        }
        if ( longDescription != null ? !longDescription.equals( that.longDescription ) : that.longDescription != null )
        {
            return false;
        }
        if ( manualInstallation != null ? !manualInstallation.equals( that.manualInstallation ) : that.manualInstallation != null )
        {
            return false;
        }
        if ( md5 != null ? !md5.equals( that.md5 ) : that.md5 != null )
        {
            return false;
        }
        if ( products != null ? !products.equals( that.products ) : that.products != null )
        {
            return false;
        }
        if ( replacedBy != null ? !replacedBy.equals( that.replacedBy ) : that.replacedBy != null )
        {
            return false;
        }
        if ( replaces != null ? !replaces.equals( that.replaces ) : that.replaces != null )
        {
            return false;
        }
        if ( requires != null ? !requires.equals( that.requires ) : that.requires != null )
        {
            return false;
        }
        if ( sha256 != null ? !sha256.equals( that.sha256 ) : that.sha256 != null )
        {
            return false;
        }
        if ( shortDescription != null ? !shortDescription.equals( that.shortDescription ) : that.shortDescription != null )
        {
            return false;
        }
        if ( downloadUrl != null ? !downloadUrl.equals( that.downloadUrl ) : that.downloadUrl != null )
        {
            return false;
        }
        if ( automatedDownloadUrl != null ? !automatedDownloadUrl.equals( that.automatedDownloadUrl ) : that.automatedDownloadUrl != null )
        {
            return false;
        }
        if ( instructionCompatibilityVersion != null ? !instructionCompatibilityVersion.equals( that.instructionCompatibilityVersion ) : that.instructionCompatibilityVersion != null )
        {
            return false;
        }
        if ( automatedInstallationSet != null ? !automatedInstallationSet.equals( that.automatedInstallationSet ) : that.automatedInstallationSet != null )
        {
            return false;
        }
        if ( type != null ? !type.equals( that.type ) : that.type != null )
        {
            return false;
        }

        return true;
    }

    public int hashCode()
    {
        int result;
        result = ( products != null ? products.hashCode() : 0 );
        result = 29 * result + ( type != null ? type.hashCode() : 0 );
        result = 29 * result + ( jira != null ? jira.hashCode() : 0 );
        result = 29 * result + ( md5 != null ? md5.hashCode() : 0 );
        result = 29 * result + ( sha256 != null ? sha256.hashCode() : 0 );
        result = 29 * result + ( fileName != null ? fileName.hashCode() : 0 );
        result = 29 * result + ( fileSize != null ? fileSize.hashCode() : 0 );
        result = 29 * result + ( longDescription != null ? longDescription.hashCode() : 0 );
        result = 29 * result + ( shortDescription != null ? shortDescription.hashCode() : 0 );
        result = 29 * result + ( manualInstallation != null ? manualInstallation.hashCode() : 0 );
        result = 29 * result + ( automatedInstallation != null ? automatedInstallation.hashCode() : 0 );
        result = 29 * result + ( requires != null ? requires.hashCode() : 0 );
        result = 29 * result + ( replacedBy != null ? replacedBy.hashCode() : 0 );
        result = 29 * result + ( replaces != null ? replaces.hashCode() : 0 );
        result = 29 * result + ( creator != null ? creator.hashCode() : 0 );
        result = 29 * result + ( lastUpdated != null ? lastUpdated.hashCode() : 0 );
        result = 29 * result + ( caseId != null ? caseId.hashCode() : 0 );
        result = 29 * result + ( licenseName != null ? licenseName.hashCode() : 0 );
        result = 29 * result + ( licenseVersion != null ? licenseVersion.hashCode() : 0 );
        result = 29 * result + ( distributionStatus != null ? distributionStatus.hashCode() : 0 );
        result = 29 * result + ( downloadUrl != null ? downloadUrl.hashCode() : 0 );
        result = 29 * result + ( automatedDownloadUrl != null ? automatedDownloadUrl.hashCode() : 0 );
        result = 29 * result + ( instructionCompatibilityVersion != null ? instructionCompatibilityVersion.hashCode() : 0 );
        result = 29 * result + ( automatedInstallationSet != null ? automatedInstallationSet.hashCode() : 0 );
        return result;
    }
}