/*
 *  Copyright (c) 1999-2002 ChurchillObjects.com  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met: Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer. Redistributions in
 *  binary form must reproduce the above copyright notice, this list of
 *  conditions and the following disclaimer in the documentation and/or other
 *  materials provided with the distribution. Neither the name of the copyright
 *  holder nor the names of its contributors may be used to endorse or promote
 *  products derived from this software without specific prior written
 *  permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
 *  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT, INCLUDING NEGLIGENCE OR OTHERWISE, ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 *  DAMAGE.
 *
 */

package churchillobjects.rss4j.model;

/**
 * Encapsulates a namespace. These are encountered early in the parsing
 * process and added to a list. They are then checked later when recognized
 * namespace elements are found. This class is immutable.
 */
public class RssNamespace {

	/**
	 * The namespace prefix, e.g. "dc".
	 */
	private String prefix;

	/**
	 * The namespace uri, e.g. "http://purl.org/dc/elements/1.1/".
	 */
	private String uri;

	/**
	 * Constructor to set the prefix and uri.
	 * @param prefix
	 * @param uri
	 */
	public RssNamespace(String prefix, String uri) {
		this.prefix = prefix;
		this.uri = uri;
	}

	/**
	 * Returns the prefix of the namespace.
	 * @return
	 */
	public String getPrefix(){
		return prefix;
	}

	/**
	 * Returns the uri of the namespace.
	 * @return
	 */
	public String getUri(){
		return uri;
	}
}