/*
 *  Copyright (c) 1999-2002 ChurchillObjects.com  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met: Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer. Redistributions in
 *  binary form must reproduce the above copyright notice, this list of
 *  conditions and the following disclaimer in the documentation and/or other
 *  materials provided with the distribution. Neither the name of the copyright
 *  holder nor the names of its contributors may be used to endorse or promote
 *  products derived from this software without specific prior written
 *  permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR
 *  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT, INCLUDING NEGLIGENCE OR OTHERWISE, ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 *  DAMAGE.
 *
 */

package churchillobjects.rss4j.parser;

/**
 * Indicates an exception occurred during parsing of the RSS document.
 * Most problems will have to do with the document not adhering to the
 * standard that it claims to support. These do not include warnings,
 * which are recovered from and added to the document object. The RSS4j toolkit
 * never hanldes this type of exception. Instead, it is used to abstract anything
 * that goes wrong (including I/O or DOM) and throw it up the stack to the client
 * code.
 */
public class RssParseException extends Exception {

	/**
	 * The nested exception for this one to contain
	 */
	private Exception exception;

	/**
	 * Constructor
	 * @param s An description of the exception
	 */
	public RssParseException(String s) {
		super(s);
	}

	/**
	 * Constructor
	 * @param s A description of the exception
	 * @param e The exception to nest inside this one
	 */
	public RssParseException(String s, Exception e) {
		super(s);
		exception = e;
	}

	/**
	 * Constructor
	 * @param e The exception to nest inside this one
	 */
	public RssParseException(Exception e) {
		exception = e;
	}

	/**
	 * Returns the nested exception.
	 * @return The nested exception
	 */
	public Exception getException(){
		return exception;
	}

	/**
	 * Returns the description of this exception,
	 * or the description of the nested exception if this
	 * one has not been set.
	 * @return The exception's description
	 */
	public String getMessage(){
		if(exception !=null && super.getMessage()==null){
			return exception.getMessage();
		}
		return super.getMessage();
	}

	/**
	 * Returns a canonical representation of this exception,
	 * or the nested exception if there is one.
	 * @return The exception as a String
	 */
	public String toString(){
		if(exception==null){
			return super.toString();
		}
		return exception.toString();
	}
}